@@ -52,7 +52,7 @@
 
 #elif defined(HAVE_CLUTTER_GTK_WIN32)
 
-#include <clutter/clutter-win32.h>
+#include <clutter/win32/clutter-win32.h>
 #include <gdk/gdkwin32.h>
 
 #endif /* HAVE_CLUTTER_GTK_{X11,WIN32} */
@@ -272,7 +272,7 @@ gtk_clutter_embed_realize (GtkWidget *widget)
   style_context = gtk_widget_get_style_context (widget);
   gtk_style_context_set_background (style_context, window);
 
-  gdk_window_add_filter (window, gtk_clutter_filter_func, widget);
+  gdk_window_add_filter (NULL, gtk_clutter_filter_func, widget);
 
 #if defined(HAVE_CLUTTER_GTK_X11)
   clutter_x11_set_stage_foreign (CLUTTER_STAGE (priv->stage), 
@@ -295,6 +295,8 @@ gtk_clutter_embed_unrealize (GtkWidget *widget)
 {
   GtkClutterEmbedPrivate *priv = GTK_CLUTTER_EMBED (widget)->priv;
 
+  gdk_window_remove_filter (NULL, gtk_clutter_filter_func, widget);
+
   if (priv->stage != NULL)
     clutter_actor_hide (priv->stage);
 
@@ -434,7 +436,6 @@ gtk_clutter_embed_key_event (GtkWidget   *widget,
 static void
 gtk_clutter_embed_style_updated (GtkWidget *widget)
 {
-  GtkClutterEmbedPrivate *priv;
   GdkScreen *screen;
   GtkSettings *gtk_settings;
   ClutterSettings *clutter_settings;
@@ -445,11 +446,10 @@ gtk_clutter_embed_style_updated (GtkWidget *widget)
   gchar *xft_hintstyle, *xft_rgba;
 #endif /* HAVE_CLUTTER_GTK_X11 */
 
-  priv = GTK_CLUTTER_EMBED (widget)->priv;
-
   if (gtk_widget_get_realized (widget))
     {
 #if 0
+      GtkClutterEmbedPrivate *priv = GTK_CLUTTER_EMBED (widget)->priv;
       GtkStyleContext *style_context;
       GtkStateFlags state_flags;
       GdkRGBA *bg_color;
